#!/bin/bash
# Script preparing visual QC of subfields
# by collecting necessary raw files into
# a subfolder within mri.
# PS 2016

subject_folder=/data2
FS_bin=/usr/local/freesurfer/bin
cd ${subject_folder}

for subject_id in $(cat /data2/list.txt); do
    
    dir_mri=${subject_folder}/${subject_id}/mri
    dir_assembly=${subject_folder}/${subject_id}/mri/assembly
    mkdir -p ${dir_assembly}
    echo =================
    echo WORKING ON ${subject_id}
    echo =================
    rm ${dir_assembly}/*mgz ${dir_assembly}/*nii ${dir_assembly}/*nii.gz
    
    # copy relevant files to assembly folder
    cp ${dir_mri}/lh.hippoSfLabels-T1.v10.mgz ${dir_mri}/assembly/left_discreteLabels.mgz
    cp ${dir_mri}/rh.hippoSfLabels-T1.v10.mgz ${dir_mri}/assembly/right_discreteLabels.mgz
    cp ${dir_mri}/nu.mgz ${dir_mri}/assembly
    cp ${dir_mri}/aparc+aseg.mgz ${dir_mri}/assembly/aparc+aseg.mgz
    
    # convert and resample all needed files
    cd ${dir_assembly}
    ${FS_bin}/mri_convert --resample_type nearest --out_orientation RAS left_discreteLabels.mgz left_discreteLabels.nii.gz
    ${FS_bin}/mri_convert --resample_type nearest --out_orientation RAS right_discreteLabels.mgz right_discreteLabels.nii.gz
    ${FS_bin}/mri_convert --resample_type nearest --out_orientation RAS aparc+aseg.mgz aparc+aseg.nii.gz
    ${FS_bin}/mri_convert --resample_type nearest --out_orientation RAS --reslice_like left_discreteLabels.mgz nu.mgz nu_left.nii.gz
    ${FS_bin}/mri_convert --resample_type nearest --out_orientation RAS --reslice_like right_discreteLabels.mgz nu.mgz nu_right.nii.gz
    ${FS_bin}/mri_convert --resample_type nearest --out_orientation RAS --reslice_like left_discreteLabels.mgz aparc+aseg.mgz aparc+aseg_highres_L.nii.gz
    ${FS_bin}/mri_convert --resample_type nearest --out_orientation RAS --reslice_like right_discreteLabels.mgz aparc+aseg.mgz aparc+aseg_highres_R.nii.gz
    
    # and unzip them to go sure they can be read in later by the load_nii command
    gunzip *.nii.gz
    
done
